@@ -5,7 +5,7 @@ class NoCategoryError(Exception):
     """
     Raised when a given category does not exist in the compendium
 
-    Parameter:
+    Parameters:
         * `target_category`: Non-existant input category that causes error.
             - type: string
     """
@@ -20,7 +20,7 @@ class NoEntryError(Exception):
 
     Parameters:
         * `target_entry`: Non-existant input entry that causes error.
-            - type: string
+            - type: string, int
     """
 
     def __init__(self, target_entry):
@@ -93,7 +93,7 @@ class compendium(object):
 
         return(get(self.url).json()["data"])
 
-    def download_entry_image(self, entry, output_file: str) -> dict:
+    def download_entry_image(self, entry, output_file: str) -> tuple:
         """
         Download the image of a compendium entry.
 
